@@ -50,6 +50,7 @@ public:
 
     bool moveSource(const QString & sourceId, int delta) override;
     int originIndex(const QString& sourceId) const;
+    QStandardItem* sourceByUrl(const QString & url) const;
 
 private:
     QStandardItem* sourceById(const QString & sourceId) const;
@@ -59,6 +60,7 @@ private:
     FlatpakInstallation *m_preferredInstallation;
     QStandardItemModel* m_sources;
     QAction* const m_flathubAction;
+    QStandardItem* m_noSourcesItem;
 };
 
 #endif // FLATPAKSOURCESBACKEND_H
