@@ -77,10 +77,10 @@ QString KNSResource::comment()
         ret = m_entry.summary();
         int newLine = ret.indexOf(QLatin1Char('\n'));
         if(newLine>0) {
-            ret=ret.left(newLine);
+            ret.truncate(newLine);
         }
-        ret = ret.replace(QRegularExpression(QStringLiteral("\\[\\/?[a-z]*\\]")), QString());
-        ret = ret.remove(QRegularExpression(QStringLiteral("<[^>]*>")));
+        ret.remove(QRegularExpression(QStringLiteral("\\[\\/?[a-z]*\\]")));
+        ret.remove(QRegularExpression(QStringLiteral("<[^>]*>")));
     }
     return ret;
 }
@@ -95,14 +95,14 @@ QString KNSResource::longDescription()
         else
             ret = ret.mid(newLine+1).trimmed();
     }
-    ret = ret.replace(QLatin1Char('\r'), QString());
-    ret = ret.replace(QStringLiteral("[li]"), QStringLiteral("\n* "));
+    ret.remove(QLatin1Char('\r'));
+    ret.replace(QStringLiteral("[li]"), QStringLiteral("\n* "));
     // Get rid of all BBCode markup we don't handle above
-    ret = ret.replace(QRegularExpression(QStringLiteral("\\[\\/?[a-z]*\\]")), QString());
+    ret.remove(QRegularExpression(QStringLiteral("\\[\\/?[a-z]*\\]")));
     // Find anything that looks like a link (but which also is not some html
     // tag value or another already) and make it a link
     static const QRegularExpression urlRegExp(QStringLiteral("(^|\\s)([-a-zA-Z0-9@:%_\\+.~#?&//=]{2,256}\\.[a-z]{2,4}\\b(\\/[-a-zA-Z0-9@:;%_\\+.~#?&//=]*)?)"), QRegularExpression::CaseInsensitiveOption);
-    ret = ret.replace(urlRegExp, QStringLiteral("<a href=\"\\2\">\\2</a>"));
+    ret.replace(urlRegExp, QStringLiteral("<a href=\"\\2\">\\2</a>"));
     return ret;
 }
 
